@@ -545,7 +545,7 @@ atk_object_class_init (AtkObjectClass *klass)
                                                         _("The accessible role of this object"),
                                                         0,
                                                         G_MAXINT,
-                                                        0,
+                                                        ATK_ROLE_UNKNOWN,
                                                         G_PARAM_READWRITE));
   g_object_class_install_property (gobject_class,
                                    PROP_LAYER,
@@ -1015,7 +1015,7 @@ atk_object_set_name (AtkObject    *accessible,
   if (klass->set_name)
     {
       /* Do not notify for initial name setting. See bug 665870 */
-      notify = (atk_object_get_name (accessible) != NULL);
+      notify = (accessible->name != NULL);
 
       (klass->set_name) (accessible, name);
       if (notify)
